@@ -15,11 +15,11 @@ Plack::App::RDF::LinkedData - A Plack application for running RDF::LinkedData
 
 =head1 VERSION
 
-Version 1.90_01
+Version 1.90_02
 
 =cut
 
- our $VERSION = '1.90_01';
+ our $VERSION = '1.90_02';
 
 
 =head1 SYNOPSIS
@@ -280,6 +280,17 @@ checked on every request to see if the description must be
 regenerated. If you use the C<add_void> feature, you can force
 regeneration on the next request by touching the file.
 
+=head2 Read-write support
+
+Some recent effort has gone into experimental write support, which for
+this module has the implications that a boolean option
+C<writes_enabled> that configures the application for writes. This is
+also meant as security, unless set to true, writes will never be
+performed. To support writes, a C<class> option can be set with a
+class name, which can be instantiated to replace
+L<RDF::LinkedData>. See L<RDF::LinkedData::RWHypermedia> for more on
+this.
+
 =head1 FEEDBACK WANTED
 
 Please contact the author if this documentation is unclear. It is
@@ -372,12 +383,23 @@ sub call {
 	return $ld->response($uri)->finalize;
 }
 
+=item C<< auth_required ( $request ) >>
+
+A method that returns true if the current request will require authorization.
+
+=cut
+
 sub auth_required {
 	my ($self, $req) = @_;
 	return ($self->{config}->{writes_enabled} && (! $self->does_read_operation($req)));
-
 }
 
+=item C<< does_read_operation ( $request ) >>
+
+A method that will return true if the current request is a pure read operation.
+
+=cut
+
 sub does_read_operation {
 	my ($self, $req) = @_;
 	my $uri = $req->uri;
