@@ -32,11 +32,11 @@ RDF::LinkedData - A Linked Data server implementation
 
 =head1 VERSION
 
-Version 1.90_01
+Version 1.90_02
 
 =cut
 
- our $VERSION = '1.90_01';
+ our $VERSION = '1.90_02';
 
 
 =head1 SYNOPSIS
@@ -79,7 +79,7 @@ Data" manner.
 =item C<< new ( store => $store, model => $model, base_uri => $base_uri, 
                 hypermedia => 1, namespaces_as_vocabularies => 1, 
                 request => $request, endpoint_config => $endpoint_config, 
-                void_config => $void_config ) >>
+                void_config => $void_config, writes_enabled => 0 ) >>
 
 Creates a new handler object based on the named parameters, given a store
 config (recommended usage is to pass a hashref of the type that can be
@@ -98,6 +98,9 @@ Finally, it can provide experimental L<Triple Pattern
 Fragments|http://www.hydra-cg.com/spec/latest/triple-pattern-fragments/>
 support.
 
+Read-write  support is  even  more experimental,  and  is provided  by
+L<RDF::LinkedData::RWHypermedia>.
+
 =item C<< BUILD >>
 
 Called by Moo to initialize an object.
@@ -257,6 +260,12 @@ has base_uri => (is => 'rw', isa => Str, default => '' );
 
 has hypermedia => (is => 'ro', isa => Bool, default => 1);
 
+=item C<< writes_enabled >>
+
+Attribute that indicates whether write operations are permitted.
+
+=cut
+  
 has writes_enabled => (is => 'ro', isa => Bool, default => 0);
 
 has namespaces_as_vocabularies => (is => 'ro', isa => Bool, default => 1);
@@ -269,6 +278,12 @@ has fragments_config => (is => 'rw', isa=>Maybe[HashRef], predicate => 'has_frag
 
 has rwhypermedia_config => (is => 'rw', isa=>Maybe[HashRef], predicate => 'has_rwhypermedia_config');
 
+=item C<< does_read_operation >>
+
+Returns or sets whether the current request is a read operation.
+
+=cut
+
 has does_read_operation => (is => 'rw', isa => Bool, default => 0);
 
 
@@ -456,7 +471,8 @@ sub response {
 	}
 
 	if ($self->has_void) {
-		my $void_resp = $self->_void_content($uri, $endpoint_path);
+	   my $void_resp = $self->_void_content($uri, $endpoint_path);
+		$self->log->error("The dataset URI does not start with the base URI") unless (index($self->void->dataset_uri->as_string, $self->base_uri) == 1);
 		return $void_resp if (defined($void_resp));
 	}
 
